@@ -79,15 +79,19 @@ class ObjectFieldLabel(hg.ContextValue):
         """
         :param fieldname: Name of the model field whose value will be rendered
         :param object_contextname: Name of the context object which provides the field value
+                                   or a Lazy which produces the object itself
         """
         super().__init__(object_contextname)
         self.fieldname = fieldname
         self.title = title
+        self.object = object_contextname
 
     def resolve(self, context):
-        label = resolve_modellookup(
-            super().resolve(context)._meta.model, self.fieldname
-        )[-1]
+        object = self.object
+        if isinstance(self.object, str):
+            object = resolve_modellookup(context, self.object)[0]
+        object = hg.resolve_lazy(object, context)
+        label = resolve_modellookup(object._meta.model, self.fieldname)[-1]
         if hasattr(label, "verbose_name"):
             return label.verbose_name
         if isinstance(label, property):
@@ -97,19 +101,24 @@ class ObjectFieldLabel(hg.ContextValue):
         return label.title() if self.title and isinstance(label, str) else label
 
 
-class ObjectFieldValue(hg.ContextValue):
+class ObjectFieldValue(hg.Lazy):
     def __init__(self, fieldname, object_contextname="object", formatter=None):
         """
         :param fieldname: Name of the model field whose value will be rendered
         :param object_contextname: Name of the context object which provides the field value
+                                   or a Lazy which produces the object itself
         :param formatter: function which takes the field value as a single argument and returns a formatted version
         """
-        super().__init__(object_contextname)
+        self.object = object_contextname
         self.fieldname = fieldname
         self.formatter = formatter
 
     def resolve(self, context):
-        object = super().resolve(context)
+        object = self.object
+        if isinstance(self.object, str):
+            object = resolve_modellookup(context, self.object)[0]
+        object = hg.resolve_lazy(object, context)
+
         parts = self.fieldname.split(".")
         # test if the value has a matching get_FIELDNAME_display function
         value = hg.resolve_lookup(
@@ -117,11 +126,12 @@ class ObjectFieldValue(hg.ContextValue):
         )
         if value is None:
             value = hg.resolve_lookup(object, self.fieldname)
-        if self.formatter:
-            return self.formatter(value)
         if isinstance(value, datetime.datetime):
             value = localtime(value)
-        return localize(value, use_l10n=settings.USE_L10N)
+        value = localize(value, use_l10n=settings.USE_L10N)
+        if self.formatter:
+            value = self.formatter(value)
+        return value
 
 
 FC = FormattedContextValue
